@@ -4,6 +4,7 @@ from __future__ import annotations
 import logging
 import os
 from pathlib import Path
+from typing import Tuple
 
 import numpy as np
 import xarray as xr
@@ -100,6 +101,20 @@ class DataSourceOutput(PydanticXArrayDataSet):
             else:
                 logger.warning(message)
 
+    def check_data_var_dim(self, data: xr.Dataset, expected_dims: Tuple[str]):
+        """Check the data var has the correct dims"""
+
+        actual_dims = data.dims
+        # check the dims are the same as expected,
+        # we are using 'set' so ordering doesnt matter
+        if set(actual_dims) != set(expected_dims):
+            message = (
+                f"Actual dims {actual_dims} does not equal {expected_dims} "
+                f"for {data.name} {self.__class__.__name__}"
+            )
+            logger.error(message)
+            raise Exception(message)
+
 
 def pad_nans(array, pad_width) -> np.ndarray:
     """Pad nans with nans"""
